@@ -1,10 +1,14 @@
+"""
+Model Utils
+-----------
+
+"""
+
 import torch
 
 
 class ModelReconstructor(torch.nn.Module):
-    def __init__(
-        self, feature_extractor, classifier, connection_fn=None
-    ) -> None:
+    def __init__(self, feature_extractor, classifier, connection_fn=None) -> None:
         super(ModelReconstructor, self).__init__()
         self.feature_extractor = feature_extractor
         self.classifier = classifier
